# Install
This document contains information regarding what needs to be installed to develop Arbie.


## Solidity
For developing Solidity it is highly recommended to setup Ganache and Truffle.

Install [NVM](https://github.com/nvm-sh/nvm).

Use NVM to install Node.js version 8:
```
nvm install 8
```

Install Truffle and Ganache-cli
```
npm install -g ganache-cli truffle
```

(Optional) Install Ganache [GUI](https://www.trufflesuite.com/ganache)

